@@ -1,4 +1,9 @@
 from .http_status_server import HttpHealthServer
 from .task_args import get_kafka_binder_brokers, get_input_channel, get_output_channel, get_args
 
-from .task_status.task_status import TaskStatus
\ No newline at end of file
+from .task_status.task_status import TaskStatus
+
+from .streaming.utils import running_on_edge
+
+#import streaming
+
